==> nextcloud-app-calendar-1%3A6.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/es_GT.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s ha publicado el calendario »%s«",
    "Hello," : "Hola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informarte que %s ha publicado el calendario »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "¡Saludos!",
    "Calendar" : "Calendario",
    "Confirm" : "Confirmar",
    "Description:" : "Descripción:",
    "Where:" : "Dónde:",
    "Location:" : "Ubicación:",
    "Today" : "Hoy",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "List" : "Lista",
    "Preview" : "Previsualizar",
    "Copy link" : "Copiar liga",
    "Edit" : "Editar",
    "Delete" : "Borrar",
    "New calendar" : "Nuevo calendario",
    "Export" : "Exportar",
    "Name" : "Nombre",
    "Deleted" : "Borrado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Borrar permanentemente",
    "Deck" : "Deck",
    "Share link" : "Compartir liga",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "Save" : "Guardar",
    "Filename" : "Nombre del archivo",
    "Cancel" : "Cancelar",
    "Automatic" : "Automático",
    "Automatic ({timezone})" : "({timezone}) automática",
    "Timezone" : "Zona horaria",
    "List view" : "Vista de lista",
    "Actions" : "Acciones",
    "or" : "o",
    "General" : "General",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Update" : "Actualizar",
    "Location" : "Ubicación",
    "Description" : "Descripción",
    "to" : "para",
    "Add" : "Agregar",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sunday" : "Domingo",
    "Your email address" : "Tu dirección de correo electrónico",
    "Notification" : "Notificación",
    "Email" : "Correo electrónico",
    "hours" : "horas",
    "days" : "días",
    "weeks" : "semanas",
    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
    "Choose a file to share as a link" : "Selecciona un archivo para compartir como enlace",
    "Delete file" : "Borrar archivo",
    "Unknown" : "Desconocido",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Tentative" : "Tentativo",
    "Attendees" : "Asistentes",
    "From" : "De",
    "To" : "Para",
    "Repeat" : "Repetir",
    "never" : "nunca",
    "after" : "después",
    "Resources" : "Recursos",
    "available" : "disponible",
    "None" : "Ninguno",
    "Global" : "Global",
    "Subscribe" : "Suscribir",
    "Personal" : "Personal",
    "Edit event" : "Editar evento",
    "All day" : "Todo el día",
    "Close" : "Cerrar",
    "Participants" : "Participantes",
    "Submit" : "Enviar",
    "Anniversary" : "Aniversario",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Other" : "Otro",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Status" : "Estatus",
    "Confirmed" : "Confirmado",
    "Categories" : "Categorías",
    "User not found" : "No se encontró el usuario",
    "Hidden" : "Oculto",
    "can edit" : "puede editar",
    "Show week numbers" : "Mostrar número de semana",
    "Show keyboard shortcuts" : "Mostrar atajos de teclado"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-app-calendar-1%3A6.1.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/es_GT.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s ha publicado el calendario »%s«",
    "Hello," : "Hola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informarte que %s ha publicado el calendario »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "¡Saludos!",
    "Calendar" : "Calendario",
    "Confirm" : "Confirmar",
    "Description:" : "Descripción:",
    "Where:" : "Dónde:",
    "Location:" : "Ubicación:",
    "Today" : "Hoy",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "List" : "Lista",
    "Preview" : "Previsualizar",
    "Copy link" : "Copiar liga",
    "Edit" : "Editar",
    "Delete" : "Borrar",
    "New calendar" : "Nuevo calendario",
    "Export" : "Exportar",
    "Name" : "Nombre",
    "Deleted" : "Borrado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Borrar permanentemente",
    "Deck" : "Deck",
    "Share link" : "Compartir liga",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "Save" : "Guardar",
    "Filename" : "Nombre del archivo",
    "Cancel" : "Cancelar",
    "Automatic" : "Automático",
    "Automatic ({timezone})" : "({timezone}) automática",
    "Timezone" : "Zona horaria",
    "List view" : "Vista de lista",
    "Actions" : "Acciones",
    "or" : "o",
    "General" : "General",
    "Files" : "Archivo",
    "Update" : "Actualizar",
    "Location" : "Ubicación",
    "Description" : "Descripción",
    "to" : "para",
    "Add" : "Agregar",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sunday" : "Domingo",
    "Your email address" : "Tu dirección de correo electrónico",
    "Notification" : "Notificación",
    "Email" : "Correo electrónico",
    "hours" : "horas",
    "days" : "días",
    "weeks" : "semanas",
    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
    "Choose a file to share as a link" : "Selecciona un archivo para compartir como enlace",
    "Delete file" : "Borrar archivo",
    "Unknown" : "Desconocido",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Tentative" : "Tentativo",
    "Attendees" : "Asistentes",
    "From" : "De",
    "To" : "Para",
    "Repeat" : "Repetir",
    "never" : "nunca",
    "after" : "después",
    "Resources" : "Recursos",
    "available" : "disponible",
    "None" : "Ninguno",
    "Global" : "Global",
    "Subscribe" : "Suscribir",
    "Personal" : "Personal",
    "Edit event" : "Editar evento",
    "All day" : "Todo el día",
    "Close" : "Cerrar",
    "Participants" : "Participantes",
    "Submit" : "Enviar",
    "Anniversary" : "Aniversario",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Other" : "Otro",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Status" : "Estatus",
    "Confirmed" : "Confirmado",
    "Categories" : "Categorías",
    "User not found" : "No se encontró el usuario",
    "Hidden" : "Oculto",
    "can edit" : "puede editar",
    "Show week numbers" : "Mostrar número de semana",
    "Show keyboard shortcuts" : "Mostrar atajos de teclado",
    "Keyboard shortcuts" : "Atajos del teclado"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
